#
# spec file for package intel-gpu-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           intel-gpu-tools
Version:        1.14
Release:        1.5
Summary:        Collection of tools for development and testing of the Intel DRM driver
License:        MIT
Group:          Development/Tools/Other
Url:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
Patch0:         n_disable-build-of-pm_rpm.patch
Patch2:         u_%{name}-1.7-fix-bashisms.patch
BuildRequires:  i2c-tools
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python3-devel
BuildRequires:  swig >= 2.0.0
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dri2proto) >= 2.6
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libdrm_intel) >= 2.4.64
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(pciaccess) >= 0.10
BuildRequires:  pkgconfig(xorg-macros) >= 1.3
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xv)

# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Intel GPU is only available on x86 and x86-64
ExclusiveArch:  %ix86 x86_64

%description
This is a collection of tools for development and testing of the Intel
DRM driver.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch2 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
rm $RPM_BUILD_ROOT/%{_libdir}/intel_aubdump.la

%files
%defattr(-,root,root)
%doc README
%doc COPYING
%dir %{_datadir}/gtk-doc/html/%{name}
%{_datadir}/gtk-doc/html/%{name}/*
%{_bindir}/*
%{_mandir}/man*/*
%{_libexecdir}/intel-gpu-tools/
%{_datadir}/intel-gpu-tools/
%{_libdir}/intel_aubdump.so

%changelog
* Fri Mar  4 2016 sndirsch@suse.com
- Update to version 1.14
  * New test: gem_create validate parameters for GEM_CREATE ioctl
    (Ankitprasad Sharma)
  * New test: gem_softpin exercise the userptr ioctl to create shared
    buffers between CPU and GPU (Vinay Belgaumkar)
  * New tests: prime_mmap_coherency/kms_mmap_write_crc cache coherency
    tests (Tiago Vignatti)
  * New test: prime_mmap mmap() on dma-buf fds (Rob Bradford)
  * New test: gem_exec_reloc sanity check of execbuf-ioctl relocations (Chris
    Wilson)
  * New test: gem_exec_basic sanity check of execbuf-ioctl rings (Chris Wilson)
  * improved igt_hang_ring() infrastructure for generic hang injection support
    in the core library (Chris Wilson)
  * new igt_pm library to collect power management testing helpers (David
    Weinehall)
  * lig/igt_vc4: VC4 support library (Eric Anholt)
  * kms_frontbuffer_tracking: included in BAT (Paulo Zanoni)
  * kms_psr_sink_crc: Add BAT test for PSR active (Rodrigo Vivi)
  * gem_wait: test superseded by gem_latency in benchmarks (Chris Wilson)
  * igt_core: Fix logging to display extended line (Derek Morton)
  * igt_core: Expand --run-subtest functionality (Derek Morton)
  * kms_force_connector_basic: various fixes and included in BAT set (Daniel
    Vetter)
  * Many other improvements and bug fixes.
* Sat Jan  2 2016 zaitor@opensuse.org
- Update to version 1.13:
  + New tests:
  - kms_atomic tests atomic mode setting.
  - core_prop_blob tests blob properties.
  - gem_request_retire targets request retirement code paths.
  - core_setmaster_vs_auth checks that drop/setMaster correctly
    transfer master state.
  + Wildcard characters are now accepted when using the
  - -run-subtest command line option to specify multiple subtests
    to run.
  + Add support for Broxton in intel_audio_dump.
  + Added Kabylake support.
  + Many other bug fixes and improvements.
- Add pkgconfig(libudev) and pkgconfig(xrandr) BuildRequires,
  configure looks for them so lets build with those supported too.
* Mon Sep 14 2015 sndirsch@suse.com
- intel-gpu-tools 1.12
  - Various new tests and tools
  - New statistical analysis functions. (Damien Lespiau)
  - New benchmark tests. (Chris Wilson)
  - Old register tools that were superseded by intel_reg have been removed.
  - Various tests have been marked "basic", to indicate they are suitable for
    use in basic acceptance testing. (Jesse Barnes)
  - Per-ring gem_storedw_loop tests combined into a single test with subtests.
    (Jesse Barnes)
  - New "aubdump" tool, used to launch an application and capture rendering to
    an AUB file. (Kristian Høgsberg Kristensen)
  - Cherryview support added to intel_display_poller. (Ville Syrjälä)
  - Skylake and Broadwell support added to gem_gpgpu_fill tests.
    (Dominik Zeromski)
  - Support for running core drm tests on any platform. (Micah Fedke)
  - Many other bug fixes
- supersedes patch 'u_build-fixes.patch"
* Fri Jun 12 2015 sndirsch@suse.com
- use correct filelist macros
* Fri Jun 12 2015 sndirsch@suse.com
- Update to version 1.11
  * Various new tests and tools
  * Single combined test list (supported by piglit since commit 8a122bb)
  * Optional dependency on libunwind to provide automatic stack traces on test
    failures. (Thomas Wood)
  * Add optional default debug and optimisation flags for tests to enable better
    stack traces and debugging. (Thomas Wood)
  * Test programs are now installed into libexec. This is useful when building a
    complete software stack for a DUT from scratch. (Building and installing
    tests can still be disabled by the --disable-tests configure flag.)
    (Joonas Lahtinen)
  * New tool to decode watermark registers (Ville Syrjälä)
  * Timeout mechanism now reports test as failed
  * Introduce intel_reg as the one Intel graphics register multitool to replace
    intel_reg_read, intel_reg_write, intel_iosf_sb_read, intel_iosf_sb_write,
    intel_vga_read, intel_vga_write, intel_reg_dumper, intel_reg_snapshot,
    and quick_dump.py. (Jani Nikula)
  * Add functions to manipulate i915.ko parameters and ensure features are enabled
    for testing. (Paulo Zanoni)
- supersedes u_Fix-pointer-cast-in-order-to-fix-build-on-32bit-arch.patch
- added new buildrequires to gtk-doc and libunwind
- added /usr/lib/intel-gpu-tools/* and /usr/share/intel-gpu-tools/* to filelist
* Tue Mar 17 2015 sndirsch@suse.com
- u_Fix-pointer-cast-in-order-to-fix-build-on-32bit-arch.patch
  * fixes build on 32bit
* Mon Mar 16 2015 sndirsch@suse.com
- Update to version 1.10
  * New frequency manipulation tool (intel_gpu_frequency)
  * Adjustments for the Solaris port (Alan Coopersmith).
  * Remove tests/NAMING-CONVENTION since it's all in the docbook now,
    to avoid divergent conventions.
  * New CRITICAL log level for really serious stuff (Thomas Wood).
  * Interactive test mode can now be enabled by the shared cmdline
    option --interactive-debug=$var (Rodrigo Vivi).
  * Improved logging to kmsg to better line up test runs with kernel
    messages (Chris Wilson).
  * Record all log levels (including disabled levels) in a ringbuffer
    and dump that on test failures for quicker diagnostics of automated
    test run results (Thomas Wood).
  * A lot of small polish all over the test library.
  * Piles of new testcases and improvements to existing ones as usual.
* Tue Jan 20 2015 sndirsch@suse.com
- reenabled post build checks
- u_build-fixes.patch
  * fix post build checks
* Sun Jan 18 2015 sfalken@opensuse.org
- Update to version 1.9:
  + Patches refactored for new sources
  + post-build-checks disabled, due to check failure:
    I: Program returns random data in a function
    E: intel-gpu-tools no-return-in-nonvoid-function
    intel_renderstate_gen8.c:441
  + Dropped:
  - n_missing_check-ndebug.h.patch
  - intel-gpu-tools-1.7.tar.bz2
  + Added:
  - intel-gpu-tools-1.9.tar.bz2
  + Changes from version 1.7
  - More Android porting
  - Fixes to documentation warnings
  - Updates to UPDATE, MAINTAINERS, and README
  - lib:
  - Fix out of tree build of version.h
  - added function to lock memory into RAM
  - add option log domain filtering
  - introduce log domains
  - igt_debugfs: Don't setup crc in _new
  - igt_debugfs: Throw away the two first CRCs
  - igt.cocci: Deal with min/max/swap
  - add swap() macro
  - always reset connectors after the state is forced
  - remove igt_edid.h
  - tests:
  - gem_tiled_swapping: use igt_info logging wrapper
  - replaced 3D test images
  - kms_cursor_crc: Restore the valid pipe/connector combo check
  - kms_mmio_vs_cs_flip: Count valid tests for all crtcs
  - kms_flip:
  * Target the back buffer with the dummy load
  * Calibrate the dummy load delay in kms_flip
  * Use fixed size (2kx2k) buffers for dummy load
  * Refactor blit code
  - Run lib/igt.cocci
  - pm_rps: vlv:
  * roundmiddle point to freq supported by HW
  * load gpu for idle min/max tests\
  * wait for freq to settleo
  - add gem_gpgpu_fill to .gitignore
  - use base edid
  - tools:
  - add missing copyright headers
  - terminate getopt_long long option arrays properly
  - drv_hangman: Remove unused function
  - kms_cursor_crc: Remove value to 'return' in a void function
  - igt/drm_read: Require that pipe 0 is active
  - igt/drm_read: Abuse read(drm)
  - intel_error_decode: Decode the ERROR register on Sandybridge
    and Ivybridge
  - gem_bad_reloc: Don't flip-flop between SKIP and PASS
* Mon Nov 17 2014 sndirsch@suse.com
- rename intel-gpu-tools-1.7-fix-bashisms.patch to
  u_intel-gpu-tools-1.7-fix-bashisms.patch according to our patch
  guidelines
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in intel_gpu_abrt script that uses bash-specific
  constructions
- add patches:
  * intel-gpu-tools-1.7-fix-bashisms.patch
* Tue Jun 10 2014 sndirsch@suse.com
- update to release 1.7; Here goes a new i-g-t quarterly release
  with the following changes:
  * Piles of API documentation for the core i-g-t testing libraries.
  * Improved igt loggin, now also with igt_vlog (for va_args printf-style
      logging).
  * Polish for the igt_debugfs library.
  * Split out igt_fb library from igt_kms, cleanup of the igt_kms functions.
  * Android porting patches (Tim Gore, Tvrtko Ursulin).
  * Piles more tests as usual.
  * Support for building libcairo based tests on Android. Set ANDROID_HAS_CAIRO=1
      in the build enviroment when you have this (Tim Gore).
  * Timeout support in igt_aux, see igt_set_timeout (Thomas).
  * Documentation for the testrunner interface like exit codes, subtest
      enumeration and log output. Should help other people to run the tests in their own framework.
  * Make swig an optional dependency (Damien).
  * Helpers for runtime pm tests in igt_aux.
- rename n_disable-build-of-pm_pc8.patch to n_disable-build-of-pm_rpm.patch,
  since test has been renamed
* Tue May  6 2014 sndirsch@suse.com
- update to release 1.6
  * Changes to support Broadwell in the test suite. (Ben, Damien, et al.)
  * Updated (now working again!) Android support from Oscar Mateo.
  * Test coverage through i-g-t is now officially an integral part of any drm/i915
    feature work and also for bugfixes. For more details see:
    http://blog.ffwll.ch/2013/11/testing-requirements-for-drmi915.html
  * Fix the gen4asm build depency handling, now that the assembler is included in
    i-g-t (Ben).
  * Improve the cairo object lifetime management of the kmstest helpers (Chris).
  * Allow register access to succeed if i915 is loaded but debugfs isn't found
    (i.e. nomodeset is used)
  * New kernel modesetting helper library for simpler testcases (Damien).
  * New structure logging support for tests. Message at the WARN level be
    reflected in the piglit result, also included igt_warn_on macros to simplify
    test asserts which should just result in warnings, but not in a test abort.
  * Broadwell support for intel_audio_dump (Mengdong Lin).
  * API documentation support (Thomas)
- n_missing_check-ndebug.h.patch
  * added missing include file in order to fix build
- refreshed n_disable-build-of-pm_pc8.patch
* Mon Apr 28 2014 sndirsch@suse.com
- added missing pkgconfig(dri2proto)
* Thu Feb  6 2014 sndirsch@suse.com
- added missing LICENSE file
* Mon Dec  9 2013 sndirsch@suse.com
- update to release 1.5
- n_disable-build-of-pm_pc8.patch
  * disables build for pm_pc8 test app for now
- removed obsolete patches
  * intel-gpu-tools-no-test.diff
  * u_intel-gpu-tools-no_m4_dir.patch
* Fri May  3 2013 sndirsch@suse.com
- renamed latest patch according to our policy
* Fri Apr 26 2013 mmeister@suse.com
- Removed AC_CONFIG_MACRO_DIR([m4]) from configure.ac to fix
  build with new automake
* Mon Aug 27 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3:
  New intel-gpu-tools release with too much stuff changed. Biggest part is
  improvements to the testsuit, but also some other neat things:
  + dpf tool for handling l3 remapping on gen7
  + robustify against wc gtt mappings
  + improvements to the reg_dumper and register read/write tools
  + haswell support
- Packaging changes:
  + Added cairo to BuildRequires (we need this now)
  + changed intel-gpu-tools-no-test.diff to speed up compilation
* Mon Jul  9 2012 dmueller@suse.com
- change it to exclusivearch, as it also does not exist on ARM
* Fri Jul  6 2012 dvaleev@suse.com
- exclude ppc, ppc64. There is no intel graphic
* Thu Apr 19 2012 tiwai@suse.de
- updated to version 1.2:
  support for recent Intel graphic chips, many fixes
  See ChangeLog for details
- Don't build test directory (to simplify the packaging)
* Wed Apr 18 2012 vuntz@opensuse.org
- Split intel-gpu-tools from xorg-x11-driver-video.
  Initial version: 1.0.2-20101210-292ae45.
